AI Module
=========

This module contains AI-powered features for video processing.

Detection
---------

.. automodule:: fmusvid.ai.detection
   :members:
   :undoc-members:

Tracking
--------

.. automodule:: fmusvid.ai.tracking
   :members:
   :undoc-members:

Speech Recognition
------------------

.. automodule:: fmusvid.ai.speech
   :members:
   :undoc-members:

.. automodule:: fmusvid.ai.speech.whisper
   :members:
   :undoc-members:

Translation
-----------

.. automodule:: fmusvid.ai.translation
   :members:
   :undoc-members:

Background Removal
------------------

.. automodule:: fmusvid.ai.background
   :members:
   :undoc-members:

Cropping
--------

.. automodule:: fmusvid.ai.cropping
   :members:
   :undoc-members:
